@@ -10,12 +10,16 @@
 ( cd opt/kde/share/doc/HTML/it/kdvi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmix ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmix ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kodo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/korn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kscd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kscd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksim ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/lisa ; rm -rf common )
@@ -28,6 +32,8 @@
 ( cd opt/kde/share/doc/HTML/it/kbounce ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbattleship ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kaboodle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kaboodle ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/khangman ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/khangman ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kfloppy ; rm -rf common )
@@ -64,6 +70,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; rm -rf common )
